@@ -5,11 +5,12 @@ from types import GeneratorType
 import numpy as np
 import yaml
 
-from . import schema, tagged, treeutil, util
+from . import config, schema, tagged, treeutil, util
 from .constants import STSCI_SCHEMA_TAG_BASE, YAML_TAG_PREFIX
 from .exceptions import AsdfConversionWarning
+from .extension._serialization_context import BlockAccess
 from .tags.core import AsdfObject
-from .versioning import _yaml_base_loader, split_tag_version
+from .versioning import _YAML_VERSION, _yaml_base_loader
 
 __all__ = ["custom_tree_to_tagged_tree", "tagged_tree_to_custom_tree"]
 
@@ -117,11 +118,12 @@ AsdfDumper.add_representer(OrderedDict, represent_ordereddict)
 # ----------------------------------------------------------------------
 # Handle numpy scalars
 
-for scalar_type in util.iter_subclasses(np.floating):
-    AsdfDumper.add_representer(scalar_type, AsdfDumper.represent_float)
 
-for scalar_type in util.iter_subclasses(np.integer):
-    AsdfDumper.add_representer(scalar_type, AsdfDumper.represent_int)
+for scalar_type in util._iter_subclasses(np.floating):
+    AsdfDumper.add_representer(scalar_type, lambda dumper, data: dumper.represent_float(float(data)))
+
+for scalar_type in util._iter_subclasses(np.integer):
+    AsdfDumper.add_representer(scalar_type, lambda dumper, data: dumper.represent_int(int(data)))
 
 
 def represent_numpy_str(dumper, data):
@@ -173,7 +175,7 @@ class AsdfLoader(_yaml_base_loader):
         yield omap
         if not isinstance(node, yaml.SequenceNode):
             msg = "while constructing an ordered map"
-            raise yaml.ConstructorError(
+            raise yaml.constructor.ConstructorError(
                 msg,
                 node.start_mark,
                 f"expected a sequence, but found {node.id}",
@@ -182,7 +184,7 @@ class AsdfLoader(_yaml_base_loader):
         for subnode in node.value:
             if not isinstance(subnode, yaml.MappingNode):
                 msg = "while constructing an ordered map"
-                raise yaml.ConstructorError(
+                raise yaml.constructor.ConstructorError(
                     msg,
                     node.start_mark,
                     f"expected a mapping of length 1, but found {subnode.id}",
@@ -190,10 +192,10 @@ class AsdfLoader(_yaml_base_loader):
                 )
             if len(subnode.value) != 1:
                 msg = "while constructing an ordered map"
-                raise yaml.ConstructorError(
+                raise yaml.constructor.ConstructorError(
                     msg,
                     node.start_mark,
-                    f"expected a single mapping item, but found {len(subnode.value): %d} items",
+                    f"expected a single mapping item, but found {len(subnode.value)} items",
                     subnode.start_mark,
                 )
             key_node, value_node = subnode.value[0]
@@ -215,14 +217,31 @@ def custom_tree_to_tagged_tree(tree, ctx, _serialization_context=None):
     annotated with tags.
     """
     if _serialization_context is None:
-        _serialization_context = ctx._create_serialization_context()
+        _serialization_context = ctx._create_serialization_context(BlockAccess.WRITE)
 
     extension_manager = _serialization_context.extension_manager
 
-    def _convert_obj(obj):
-        converter = extension_manager.get_converter_for_type(type(obj))
+    def _convert_obj(obj, converter):
         tag = converter.select_tag(obj, _serialization_context)
+        # if select_tag returns None, converter.to_yaml_tree should return a new
+        # object which will be handled by a different converter
+        converters_used = set()
+        while tag is None:
+            converters_used.add(converter)
+            obj = converter.to_yaml_tree(obj, tag, _serialization_context)
+            try:
+                converter = extension_manager.get_converter_for_type(type(obj))
+            except KeyError:
+                # no converter supports this type, return it as-is
+                yield obj
+                return
+            if converter in converters_used:
+                msg = "Conversion cycle detected"
+                raise TypeError(msg)
+            tag = converter.select_tag(obj, _serialization_context)
+        _serialization_context.assign_object(obj)
         node = converter.to_yaml_tree(obj, tag, _serialization_context)
+        _serialization_context.assign_blocks()
 
         if isinstance(node, GeneratorType):
             generator = node
@@ -247,19 +266,30 @@ def custom_tree_to_tagged_tree(tree, ctx, _serialization_context=None):
         if generator is not None:
             yield from generator
 
+    cfg = config.get_config()
+    convert_ndarray_subclasses = cfg.convert_unknown_ndarray_subclasses
+    converters_cache = {}
+
     def _walker(obj):
-        if extension_manager.handles_type(type(obj)):
-            return _convert_obj(obj)
-
-        tag = ctx._type_index.from_custom_type(
-            type(obj),
-            ctx.version_string,
-            _serialization_context=_serialization_context,
-        )
-
-        if tag is not None:
-            return tag.to_tree_tagged(obj, ctx)
+        typ = type(obj)
+        if typ in converters_cache:
+            return converters_cache[typ](obj)
+        if extension_manager.handles_type(typ):
+            converter = extension_manager.get_converter_for_type(typ)
+            converters_cache[typ] = lambda obj, _converter=converter: _convert_obj(obj, _converter)
+            return _convert_obj(obj, converter)
+        if convert_ndarray_subclasses and isinstance(obj, np.ndarray):
+            warnings.warn(
+                f"A ndarray subclass ({type(obj)}) was converted as a ndarray. "
+                "This behavior will be removed from a future version of ASDF. "
+                "See https://asdf.readthedocs.io/en/latest/asdf/config.html#convert-unknown-ndarray-subclasses",
+                AsdfConversionWarning,
+            )
+            converter = extension_manager.get_converter_for_type(np.ndarray)
+            converters_cache[typ] = lambda obj, _converter=converter: _convert_obj(obj, _converter)
+            return _convert_obj(obj, converter)
 
+        converters_cache[typ] = lambda obj: obj
         return obj
 
     return treeutil.walk_and_modify(
@@ -279,7 +309,7 @@ def tagged_tree_to_custom_tree(tree, ctx, force_raw_types=False, _serialization_
     tags, to a tree containing custom data types.
     """
     if _serialization_context is None:
-        _serialization_context = ctx._create_serialization_context()
+        _serialization_context = ctx._create_serialization_context(BlockAccess.READ)
 
     extension_manager = _serialization_context.extension_manager
 
@@ -294,43 +324,16 @@ def tagged_tree_to_custom_tree(tree, ctx, force_raw_types=False, _serialization_
         if extension_manager.handles_tag(tag):
             converter = extension_manager.get_converter_for_tag(tag)
             obj = converter.from_yaml_tree(node.data, tag, _serialization_context)
+            _serialization_context.assign_object(obj)
+            _serialization_context.assign_blocks()
             _serialization_context._mark_extension_used(converter.extension)
             return obj
 
-        tag_type = ctx._type_index.from_yaml_tag(ctx, tag, _serialization_context=_serialization_context)
-        # This means the tag did not correspond to any type in our type index.
-        if tag_type is None:
-            if not ctx._ignore_unrecognized_tag:
-                warnings.warn(
-                    f"{tag} is not recognized, converting to raw Python data structure",
-                    AsdfConversionWarning,
-                )
-            return node
-
-        tag_name, tag_version = split_tag_version(tag)
-        # This means that there is an explicit description of versions that are
-        # compatible with the associated tag class implementation, but the
-        # version we found does not fit that description.
-        if tag_type.incompatible_version(tag_version):
+        if not ctx._ignore_unrecognized_tag:
             warnings.warn(
-                f"Version {tag_version} of {tag_name} is not compatible with any existing tag implementations",
+                f"{tag} is not recognized, converting to raw Python data structure",
                 AsdfConversionWarning,
             )
-            return node
-
-        # If a tag class does not explicitly list compatible versions, then all
-        # versions of the corresponding schema are assumed to be compatible.
-        # Therefore we need to check to make sure whether the conversion is
-        # actually successful, and just return a raw Python data type if it is
-        # not.
-        try:
-            return tag_type.from_tree_tagged(node, ctx)
-        except TypeError as err:
-            warnings.warn(
-                f"Failed to convert {tag} to custom type (detail: {err}). Using raw Python data structure instead",
-                AsdfConversionWarning,
-            )
-
         return node
 
     return treeutil.walk_and_modify(
@@ -393,8 +396,6 @@ def dump_tree(tree, fd, ctx, tree_finalizer=None, _serialization_context=None):
         tree_finalizer(tree)
     schema.validate(tree, ctx)
 
-    yaml_version = tuple(int(x) for x in ctx.version_map["YAML_VERSION"].split("."))
-
     # add yaml %TAG definitions from extensions
     if _serialization_context:
         for ext in _serialization_context._extensions_used:
@@ -408,7 +409,7 @@ def dump_tree(tree, fd, ctx, tree_finalizer=None, _serialization_context=None):
         Dumper=AsdfDumper,
         explicit_start=True,
         explicit_end=True,
-        version=yaml_version,
+        version=_YAML_VERSION,
         allow_unicode=True,
         encoding="utf-8",
         tags=tags,
